(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     84691,       2586]
NotebookOptionsPosition[     38954,       1485]
NotebookOutlinePosition[     74303,       2252]
CellTagsIndexPosition[     74260,       2249]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Notebook Intro8.nb:\nA Brief Introduction to ",
  PrivateFontOptions->{"FontPostScriptName"->Automatic}],
 StyleBox["Mathematica",
  FontSlant->"Italic",
  PrivateFontOptions->{"FontPostScriptName"->Automatic}]
}], "Title",
 Evaluatable->False,
 CellChangeTimes->{3.6011107754769917`*^9},
 AspectRatioFixed->True],

Cell["\<\
(Version 1.0, 11 February 2014, Uwe Grimm)\
\>", "Subtitle",
 CellChangeTimes->{{3.601110768830624*^9, 3.60111077241076*^9}}],

Cell[TextData[{
 "prepared by Uwe Grimm for the summer school on Aperiodic Order, Edmonton, \
200",
 Cell[BoxData[
  FormBox["0", TraditionalForm]]],
 "\n(based on a previous file by Rudolf A. R\[ODoubleDot]mer and Uwe Grimm)"
}], "Subtitle",
 Evaluatable->False,
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontSize->14,
 FontSlant->"Italic",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["What is a Notebook and how to use it?", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "What you see now is a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook. It contains text, graphics, numerical calculations, definitions \
of functions, and programs. On the right hand side of each notebook, you will \
see brackets, which enclose different parts of the text (\"",
 StyleBox["cells",
  FontColor->RGBColor[1, 0, 0]],
 "\") in different levels. Using these brackets, you can selectively tell ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " which statement to evaluate. Just ",
 StyleBox["double-click",
  FontColor->RGBColor[0, 0, 1]],
 " on the cell bracket and then hit ",
 StyleBox["SHIFT+RETURN",
  FontColor->RGBColor[0, 0, 1]],
 " together.\n\nSome cells (like this one) contain only text and cannot be \
evaluated. You can recognize different cell types by the form of their \
brackets.\[RawEscape]There may also be so-called initialization cells which \
are executed automatically when the notebook file is opened.\n\nYou can do \
almost anything (like changing cell types, cutting and pasting text, find \
words in the notebook, changing text color,...) by using the ",
 StyleBox["menus",
  FontColor->RGBColor[1, 0, 0]],
 ". For some commands, also the key code is given in the menu, which can be \
used alternatively. However, one has to take care to the definition of the ",
 StyleBox["Mod1",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["Mod2",
  FontColor->RGBColor[0, 0, 1]],
 " keys - these can be set under ",
 StyleBox["Preferences",
  FontColor->RGBColor[1, 0, 0]],
 " in the ",
 StyleBox["Edit",
  FontColor->RGBColor[1, 0, 0]],
 " menu.\n\nYou can also format text and equations in a style that suits your \
personal taste. Besides choosing colors and text fonts, also Greek letters \
such as \[Alpha], \[Beta], \[Gamma] ... and many more special symbols \
available. these allow you to write also formulas in a \"readable\" form, for \
instance ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[CapitalGamma]", "(", "z", ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"z", "-", "1"}]], 
      SuperscriptBox["e", 
       RowBox[{"-", "t"}]], "d", "t"}]}]}], TraditionalForm]]],
 " for the \[CapitalGamma] function.  You can find information about the use \
of such symbols, as well as the explanation of built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands and additional ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " packages in the ",
 StyleBox["Help",
  FontColor->RGBColor[1, 0, 0]],
 " menu.\n\nNow, close this section by ",
 StyleBox["double-clicking ",
  FontColor->RGBColor[0, 0, 1]],
 "on the enclosing bracket and open the next part..."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Calculations", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "You can do arithmetics with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " just as you would on a calculator. For instance, type the input ",
 StyleBox["5+7",
  FontColor->RGBColor[0, 0, 1]],
 ", then hit ",
 StyleBox["SHIFT+RETURN",
  FontColor->RGBColor[0, 0, 1]],
 " together and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will print the result 12. Try it here:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["5+7", "Input",
 AspectRatioFixed->True],

Cell["You can calculate special function values", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Gamma", "[", "1.25", "]"}]], "Input"],

Cell["or even integrals", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["NIntegrate[ Sin[ Sin[x] ], {x,0,Pi} ]", "Input",
 AspectRatioFixed->True],

Cell["and many other things.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
If you terminate an expression by a semicolon, and evaluate the expression, \
the output is suppressed\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["5+7;", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "At each executed cell you find something like \"",
 StyleBox["In[4]:=",
  FontColor->RGBColor[0, 0, 1]],
 "\" that denotes the 4th input you gave in this session. When executed \
again, it is overwritten by the most recent value. Similarly, the output is \
number \"",
 StyleBox["Out[4]=",
  FontColor->RGBColor[0, 0, 1]],
 "\", and you can use it in later expressions, for example"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Out[4]^2", "Input",
 AspectRatioFixed->True],

Cell["or", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["%4^2", "Input",
 AspectRatioFixed->True],

Cell["\<\
For the recent outputs, there is a shorter version:
% denotes the most recent output, %% the previous one, and so on.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Informations about a command can be obtained via the ",
 StyleBox["Help",
  FontColor->RGBColor[1, 0, 0]],
 " menu, or by entering a question mark with a command name, where a star * \
stands for any expression:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["?*Int*", "Input",
 AspectRatioFixed->True],

Cell["?NIntegrate", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "Note that upper- and lowercase letters are different! Built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands start with an uppercase letter."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "One of the nice features of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is that you can easily plot your results. Here is a simple example of a \
real function"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"Exp", "[", "x", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "If you ",
 StyleBox["click",
  FontColor->RGBColor[0, 0, 1]],
 " on that graphical output, a frame will occur, which allows you to resize \
the graphics according to your wish."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
There is a variety of commands that allows you to plot things in various \
ways, for example\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"x", "+", 
     RowBox[{"Sin", "[", "y", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"x", "+", 
     RowBox[{"Sin", "[", "y", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "Here, the numbers at the end specify the range of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " values. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["You can also produce 3D parametric surfaces", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", 
     RowBox[{"u", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], ",", 
     FractionBox["t", "3"]}], "}"}], ",", "\[IndentingNewLine]", 
   "                                   ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
   "                                    ", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"Quaternion", "[", 
       RowBox[{"1", ",", "1", ",", "1", ",", "0"}], "]"}], "]"}], "Ticks"}], 
    "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.601111499924368*^9, 3.601111524686982*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\"",
 StyleBox["Ticks->None",
  FontColor->RGBColor[0, 0, 1]],
 "\" is an option that tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " not to use tick marks on the axes. There are many other options on plots, \
to give you an impression try"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Options[Plot3D]", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "which lists the available options and their pre-defined values, or the \
actual values if you use the commands ",
 StyleBox["Options",
  FontColor->RGBColor[0, 0, 1]],
 " or ",
 StyleBox["FullOptions",
  FontColor->RGBColor[0, 0, 1]],
 " for a specific plot, for example"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"x", "+", 
     RowBox[{"Sin", "[", "y", "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
   "             ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   "             ", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", "\[IndentingNewLine]", 
   "             ", 
   RowBox[{"ColorOutput", "\[Rule]", "GrayLevel"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "25"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.601111560344833*^9, 3.601111575873542*^9}}],

Cell[BoxData[
 RowBox[{"Options", "[", "%", "]"}]], "Input"],

Cell["\<\
One can furthermore construct pictures from lines, points, circles, disks, \
polygon and much more, and use different colors, for example\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RGBColor", "[", 
       RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", "     ", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
      RowBox[{"Polygon", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]"}], "5"], "]"}], ",", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]"}], "5"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"4", " ", "\[Pi]"}], "5"], "]"}], ",", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"4", " ", "\[Pi]"}], "5"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"6", " ", "\[Pi]"}], "5"], "]"}], ",", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"6", " ", "\[Pi]"}], "5"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"8", " ", "\[Pi]"}], "5"], "]"}], ",", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"8", " ", "\[Pi]"}], "5"], "]"}]}], "}"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
      RowBox[{"Disk", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox["3", "2"], ",", "0"}], "}"}], ",", 
        FractionBox["1", "4"]}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.601111587609005*^9, 3.601111600381411*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The option ",
 StyleBox["AspectRatio -> Automatic",
  FontColor->RGBColor[0, 0, 1]],
 " forces ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to scale the figure according to its natural lengths."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "The command ",
 StyleBox["Show",
  FontColor->RGBColor[0, 0, 1]],
 " can also be used to combine several plots into one:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plt1", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plt2", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Cos", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"plt1", ",", "plt2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.6011116202911663`*^9, 3.6011117226222773`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Algebra and Calculus", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is also, and most importantly, an algebraic problem solver."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["9(2+x)(x+y)+(x+y)^2", "Input",
 AspectRatioFixed->True],

Cell["You can expand such expressions", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell["and factor them", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Factor", "[", "%", "]"}]], "Input"],

Cell["or extract the coefficients of certain variables", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input"],

Cell["We now want to take the 3rd power of this expression.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Expand[ %^3 ]", "Input",
 AspectRatioFixed->True],

Cell["This looks weird, so lets simplify it.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Simplify[%]", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "We can also integrate algebraically. The ",
 StyleBox["//Simplify",
  FontColor->RGBColor[0, 0, 1]],
 " does the same job as above. It is an example fo the many ways one can \
program ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Integrate[x^2 Sin[x]^2, x] //Simplify", "Input",
 AspectRatioFixed->True],

Cell["Differentiation works as follows", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input"],

Cell["\<\
For a function of several variables, you can for instance calculate the \
second derivative with respect to x and the first derivative with respect to \
y as follows\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.6011117507856693`*^9, 3.601111753592042*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"9", 
     RowBox[{"(", 
      RowBox[{"2", "+", "x"}], ")"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "+", "y"}], ")"}], "^", "3"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "+", "y"}], ")"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "1"}], "}"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving Equations", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["This is an equation.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["x^3 - 7 x^2 - 3 a x == 0", "Input",
 AspectRatioFixed->True],

Cell["What's the solution?", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solve[ %, x ]", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "The output is a list of ",
 StyleBox["rules, ",
  FontColor->RGBColor[1, 0, 0]],
 "specifying replacements of certain varibales in the expression.  These can \
be applied to expressions as follows"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["(x^3 - 7 x^2)/(3 a) /. % //Simplify", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "see the section on ",
 StyleBox["rules",
  FontColor->RGBColor[0, 0, 1]],
 " for more detail."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Lists", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Nearly everything in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is a list. The next command generates a matrix whose elements are \
represented as lists of lists."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["matrix = Table[1/(i+j-1),{i,3},{j,3}]", "Input",
 AspectRatioFixed->True],

Cell["Let's find the inverse matrix.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["invmatrix = Inverse[matrix]", "Input",
 AspectRatioFixed->True],

Cell["Is it really the inverse?", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["matrix . invmatrix //MatrixForm", "Input",
 AspectRatioFixed->True],

Cell["Looks OK to me. One more check...", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["invmatrix . matrix //MatrixForm", "Input",
 AspectRatioFixed->True],

Cell["\<\
Supposse we have measured a signal and now want to plot this. \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"signallist", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["i", "2"], ",", 
      RowBox[{"i", "+", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.5`"}], "}"}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"ListPlot", "[", "signallist", "]"}]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "There are lots of nice ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands to handle lists. You can access a single element by"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["matrix[[3]][[2]]", "Input",
 AspectRatioFixed->True],

Cell["or by", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["matrix[[3,2]]", "Input",
 AspectRatioFixed->True],

Cell["The number of elements in a list can be seen as follows", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Length[matrix]", "Input",
 AspectRatioFixed->True],

Cell["Dimensions[matrix]", "Input",
 AspectRatioFixed->True],

Cell["\<\
More about things you cando with lists in the follwing section...\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Manipulating Lists", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["You can concatenate lists", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Join[{1,2,3},{2,3,4},{3,4,5}]", "Input",
 AspectRatioFixed->True],

Cell["sort them", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Sort[%]", "Input",
 AspectRatioFixed->True],

Cell["or keep only the different elements", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Union[%]", "Input",
 AspectRatioFixed->True],

Cell["You can reverse the order of the elements", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Reverse[%]", "Input",
 AspectRatioFixed->True],

Cell["or shift them cyclically", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["RotateRight[%,2]", "Input",
 AspectRatioFixed->True],

Cell["\<\
Of course, you can calculate intersections and complements of lists\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Intersection[%,{0,1,2}]", "Input",
 AspectRatioFixed->True],

Cell["Complement[%%,{0,1,2}]", "Input",
 AspectRatioFixed->True],

Cell["You can also select certain elements, for instance", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Select[{1,3,5,7,9},#>3&]", "Input",
 AspectRatioFixed->True],

Cell["\<\
selects those elements that are greater than 3. For the structure of the \
function that performs the comparison see the section on functions below.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
One can check whether something occurs in a list, and compute where is occurs:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["MemberQ[{1,3,5,7,9},3]", "Input",
 AspectRatioFixed->True],

Cell["Position[{1,3,5,7,9},3]", "Input",
 AspectRatioFixed->True],

Cell["MemberQ[{1,3,5,7,9},4]", "Input",
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Executing Commands on Lists", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "There are several ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands that allow you to execute functions on elements of lists in a \
selective way. If f is some arbitrary function, you can for instance use"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Map[f,matrix]", "Input",
 AspectRatioFixed->True],

Cell["to apply it to all elements. ", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Map[f,matrix,{2}]", "Input",
 AspectRatioFixed->True],

Cell["\<\
applies it to all elements of the elements of the list, whereas\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Map[f,matrix,2]", "Input",
 AspectRatioFixed->True],

Cell["\<\
applies it to both elements at first and second levels. MapIndexed allows you \
to also access the position of the element in the list:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["MapIndexed[f,{1,3,5,7,9}]", "Input",
 AspectRatioFixed->True],

Cell["Another useful command is Apply, which acts as follows", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Apply[f,matrix,2]", "Input",
 AspectRatioFixed->True],

Cell["\<\
which makes it very easy to do things as sum all elements in a list:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Apply[Plus,{1,3,5,7,9}]", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "Another nice command is ",
 StyleBox["Nest",
  FontColor->RGBColor[0, 0, 1]],
 " which allows you to apply a function repeatedly"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Nest", "[", 
  RowBox[{"f", ",", "x", ",", "4"}], "]"}]], "Input"],

Cell[TextData[{
 "and ",
 StyleBox["Nestlist",
  FontColor->RGBColor[0, 0, 1]],
 " gives you a list of all intermediate steps"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"NestList", "[", 
  RowBox[{"f", ",", "x", ",", "4"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rules", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "You can replace variables in an expression by applying a ",
 StyleBox["rule",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", "+", "1"}], ")"}], "^", "5"}], "]"}], " ", "/.", " ", 
  RowBox[{"{", 
   RowBox[{"x", " ", "\[Rule]", " ", 
    RowBox[{"2", " ", "y"}]}], "}"}]}]], "Input"],

Cell[TextData[{
 "But ",
 StyleBox["rules",
  FontColor->RGBColor[0, 0, 1]],
 " can do much more than that, for example"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"tab1", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"i", "+", "j", "-", "1"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "8"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "8"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"tab1", " ", "/.", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"n_Integer", " ", "/;", " ", 
     RowBox[{
      RowBox[{"Mod", "[", 
       RowBox[{"n", ",", "2"}], "]"}], "\[Equal]", "0"}]}], ")"}], 
   "\[RuleDelayed]", " ", 
   RowBox[{"n", "/", "2"}]}]}]], "Input"],

Cell["\<\
divides all even numbers in the list by two, and the following command \
applies the rule recursively until nothing changes any more, thus in this \
case until all numbers are odd:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"tab1", " ", "//.", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"n_Integer", " ", "/;", " ", 
     RowBox[{
      RowBox[{"Mod", "[", 
       RowBox[{"n", ",", "2"}], "]"}], "\[Equal]", "0"}]}], ")"}], 
   "\[RuleDelayed]", " ", 
   RowBox[{"n", "/", "2"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Strings", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Thus ",
 StyleBox["rules",
  FontColor->RGBColor[0, 0, 1]],
 " are extremely useful for recursive replacements, for example"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fibo", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{"{", "\"\<S\>\"", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"fibo", "[", "1", "]"}], " ", "=", " ", 
   RowBox[{"{", "\"\<L\>\"", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"fibo", "[", "n_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"fibo", "[", "n", "]"}], " ", "=", " ", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"fibo", "[", 
       RowBox[{"n", "-", "1"}], "]"}], " ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<S\>\"", "\[Rule]", 
         RowBox[{"{", "\"\<L\>\"", "}"}]}], ",", " ", 
        RowBox[{"\"\<L\>\"", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<L\>\"", ",", "\"\<S\>\""}], "}"}]}]}], "}"}]}], 
     "]"}]}]}], ";"}]}], "Input"],

Cell["yields the Fibonacci sequence of letters S and L", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"fibo", "[", "10", "]"}]], "Input"],

Cell[TextData[{
 "Here, the variables \"L\" and \"S\" here are treated as ",
 StyleBox["strings",
  FontColor->RGBColor[0, 0, 1]],
 ", therefore you can apply string functions to manipulate them, for example"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"StringJoin", ",", 
   RowBox[{"fibo", "[", "10", "]"}]}], "]"}]], "Input"],

Cell["\<\
makes it one word. Here are some more functions that you can use to \
manipulate strings:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"?", "String*"}]], "Input"],

Cell[TextData[{
 "Note that the funny-looking definition ",
 StyleBox["fibo[n_]:=fibo[n]=...", "Input"],
 "  tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " that it should keep intermediate results in memory. You can see this by\n\
executing the command"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"?", "fibo"}]], "Input"],

Cell[TextData[{
 "which, besides the definition entered above, lists the values that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " stored\ninternally."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Variants of Commands", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "For many ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands, there exist several variants that can be used synonymously. For \
example, you can always find out about ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s internal treatment of an expression you entered in the following way"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"tab2", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"i", "*", 
      RowBox[{"x", "^", "i"}]}], "+", 
     RowBox[{"3", "*", "i"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "5"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"FullForm", "[", "tab2", "]"}]], "Input"],

Cell["\<\
This shows that, for instance, the following expressions are identical:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{"List", "[", 
  RowBox[{"1", ",", "2", ",", "3"}], "]"}], "\n", 
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "Input"],

Cell[BoxData[{
 RowBox[{"Plus", "[", 
  RowBox[{"a", ",", "b"}], "]"}], "\n", 
 RowBox[{"a", "+", "b"}]}], "Input"],

Cell[BoxData[{
 RowBox[{"Times", "[", 
  RowBox[{"a", ",", "b"}], "]"}], "\n", 
 RowBox[{"a", "*", "b"}], "\n", 
 RowBox[{"a", " ", "b"}]}], "Input"],

Cell[BoxData[{
 RowBox[{"Power", "[", 
  RowBox[{"x", ",", "3"}], "]"}], "\n", 
 RowBox[{"x", "^", "3"}]}], "Input"],

Cell["and so on. Some more examples:", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{"Rule", "[", 
  RowBox[{"x", ",", "1"}], "]"}], "\n", 
 RowBox[{"x", "\[Rule]", "1"}]}], "Input"],

Cell[BoxData[{
 RowBox[{"RuleDelayed", "[", 
  RowBox[{"x_", ",", 
   SuperscriptBox["x", "2"]}], "]"}], "\n", 
 RowBox[{"x_", "\[RuleDelayed]", 
  RowBox[{"x", "^", "2"}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{"Dot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], ".", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{"Apply", "[", 
  RowBox[{"Plus", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "\n", 
 RowBox[{"Plus", " ", "@@", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{"Map", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "\n", 
 RowBox[{"f", "/@", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "Input"],

Cell["\<\
so there are some useful abbreviations if you are able to remember these \
symbols...\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "There are several ways to define functions in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the shortest is as follows:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["func1 = #1^2+#2^2&", "Input",
 AspectRatioFixed->True],

Cell["which is short for", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["func2 = Function[#1^2+#2^2]", "Input",
 AspectRatioFixed->True],

Cell["or", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["func3 = Function[{x3,y3},x3^2+y3^2]", "Input",
 AspectRatioFixed->True],

Cell["\<\
In the first two versions, #1 and #2 denote the first and second argument, \
respectively. The functions can be applied to arguments as follows\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["func1[3,4]", "Input",
 AspectRatioFixed->True],

Cell["func2[3,4]", "Input",
 AspectRatioFixed->True],

Cell["func3[3,4]", "Input",
 AspectRatioFixed->True],

Cell["\<\
so all the definitions are identical (except that the two variables are given \
explicit names in the third version).\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Programming", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "We now want to write small programs in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Here is a simple ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " program which generates the matrix we already encountered above, but now \
for any dimension n."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Hilbert[n_] :=
 Table[1/(i+j-1),{i,n},{j,n}]\
\>", "Input",
 AspectRatioFixed->True],

Cell["We try it", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Hilbert[3]", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "The characters followed by one or more  underscores (these are called \
patterns in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ") are treated variables that are replaced by the actual value if the \
command is executed. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has several types of variables (one can use one symbol for an unspecified \
number of variables, provide default values, or specify the type of variable, \
for instance). The \":=\" is a delayed assignment, the right-hand side is \
only calculated when the command is used. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
multiplyintegers[n__Integer] := 
  Apply[Times,List[n]];\
\>", "Input",
 AspectRatioFixed->True],

Cell["multiplyintegers[3]", "Input",
 AspectRatioFixed->True],

Cell["multiplyintegers[1,2,3,4]", "Input",
 AspectRatioFixed->True],

Cell["multiplyintegers[1,2.3]", "Input",
 AspectRatioFixed->True],

Cell["\<\
The last expression is not evaluated since the definition of multiplyintegers \
applies only to integer variables.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "For longer or more complex tasks, you may want to write small programs that \
have local variables and execute a number of commands in a row. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", this is done by writing a so-called ",
 StyleBox["Module",
  FontColor->RGBColor[0, 0, 1]],
 ", for instance you can write a routine that removes all elements larger \
than a certain number from a list and then squares the elements and sums them \
as follows:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
sumofsquares[lis_,maxval_] :=
Module[{res},
       res = Select[lis,#<=maxval&];
       res = Map[#^2&,res];
       res = Apply[Plus,res];
       Return[res]];\
\>", "Input",
 AspectRatioFixed->True],

Cell["sumofsquares[{1,3,5,7,9},5]", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "Here, res is a local variable that is not defined outside the ",
 StyleBox["Module",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData["res"], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Packages"
}], "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Previous versions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " used to come with various packages of specialized applications. The newer \
versions have many of these already included, so it is not necessary to load \
them. For example, Fourier transforms are calculated simply by using the \
FourierTransform command"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.60111093255684*^9, 3.601111008308432*^9}, {
  3.601111165156722*^9, 3.60111116843676*^9}},
 AspectRatioFixed->True],

Cell["?FourierTransform", "Input",
 CellChangeTimes->{{3.601111012056016*^9, 3.601111013517475*^9}, 
   3.601112105795516*^9},
 AspectRatioFixed->True],

Cell["FourierTransform[Exp[-t^2],t,w]", "Input",
 AspectRatioFixed->True],

Cell["FourierTransform[Sin[t],t,w]", "Input",
 AspectRatioFixed->True],

Cell["\<\
Here is one example of a package that allows you to work with quaternions:\
\>", "Text",
 CellChangeTimes->{{3.601111242577334*^9, 3.601111286806931*^9}, {
  3.601111385205863*^9, 3.601111394083995*^9}}],

Cell[BoxData[
 RowBox[{"<<", "Quaternions`"}]], "Input",
 CellChangeTimes->{{3.601111206820456*^9, 3.6011112136578417`*^9}}],

Cell[BoxData[
 RowBox[{"?", "Quaternions`*"}]], "Input",
 CellChangeTimes->{{3.60111122651641*^9, 3.601111236607987*^9}}],

Cell[BoxData[
 RowBox[{"Sqrt", "[", 
  RowBox[{"Quaternion", "[", 
   RowBox[{"1", ",", "1", ",", "1", ",", "0"}], "]"}], "]"}]], "Input",
 CellID->1510471140],

Cell[BoxData[
 RowBox[{"IntegerQuaternionQ", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.601111314062232*^9, 3.6011113509795713`*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{710, 854},
WindowMargins->{{168, Automatic}, {Automatic, 31}},
ShowSelection->True,
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{24, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 12], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{8, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 8], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, 
          CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 5, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, CellFrameLabelMargins -> 
          6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], CellMargins -> {{12, Inherited}, {20, 40}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, TextAlignment -> Center, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 36, FontWeight -> "Bold", FontColor -> 
             RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 40}}, TextAlignment -> Center, 
             LineSpacing -> {1, 0}, FontSize -> 44], 
            Cell[
             StyleData["Title", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, TextAlignment -> Center, 
             FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], 
             CellMargins -> {{2, 10}, {12, 30}}, TextAlignment -> Center, 
             FontSize -> 24]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], 
             CellMargins -> {{12, Inherited}, {20, 15}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, TextAlignment -> Center, CounterIncrements -> "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 24, FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 20}}, TextAlignment -> Center, 
             LineSpacing -> {1, 0}, FontSize -> 36, FontColor -> 
             RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 4}}, TextAlignment -> Center, 
             FontSize -> 14, FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{2, 10}, {12, 8}}, TextAlignment -> Center, 
             FontSize -> 18, FontColor -> RGBColor[1, 0, 0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], 
             CellMargins -> {{12, Inherited}, {20, 15}}, 
             CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {8, 8}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{2, 10}, {12, 8}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 18, FontWeight -> "Bold", 
             FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{40, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{13, 0}, {7, 22}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Times", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{36, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{16, Inherited}, {6, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {7, 22}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> 
             "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{34, 10}, {11, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{17, Inherited}, {6, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{9, 0}, {7, 14}}, FontSize -> 11]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {7, 7}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Text", FontSize -> 
             18, FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 22], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {6, 6}},
              LineSpacing -> {1, 1}, FontSize -> 17], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}, 
             TextJustification -> 0.5, FontSize -> 16]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {6, 6}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "SmallText", 
             FontFamily -> "Helvetica", FontSize -> 9, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{24, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {5, 5}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{2, 2}, {5, 5}}, TextJustification -> 0.5, 
             FontSize -> 7]}, Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). ", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{45, 10}, {5, 7}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, DefaultFormatType -> 
             DefaultInputFormatType, AutoItalicWords -> {}, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> 
             "Input", FontSize -> 18, FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{72, Inherited}, {8, 10}}, LineSpacing -> {1, 0},
              FontSize -> 17], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {2, 3}}, FontSize -> 12], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{39, 0}, {4, 6}},
              LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 10]}, 
           Closed]], 
         Cell[
          StyleData["InputOnly"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, DefaultFormatType -> 
          DefaultInputFormatType, AutoItalicWords -> {}, FormatType -> 
          InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
          LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> 
          "Input", StyleMenuListing -> None, FontWeight -> "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{47, 10}, {7, 5}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, DefaultFormatType -> 
             DefaultOutputFormatType, AutoItalicWords -> {}, FormatType -> 
             InputForm, CounterIncrements -> "Output", FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{72, Inherited}, {10, 8}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{41, Inherited}, {3, 2}}], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{39, 0}, {6, 4}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Message", StyleMenuListing -> None, 
             FontSize -> 16, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontColor -> GrayLevel[0]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Print", StyleMenuListing -> None, FontSize -> 
             16], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{4, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
             10], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             ImageMargins -> {{62, Inherited}, {Inherited, 0}}], 
            Cell[
             StyleData["Graphics", "Condensed"], 
             ImageMargins -> {{38, Inherited}, {Inherited, 0}}, Magnification -> 
             0.6], 
            Cell[
             StyleData["Graphics", "Printout"], 
             ImageMargins -> {{30, Inherited}, {Inherited, 0}}, Magnification -> 
             0.8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 9], 
            Cell[
             StyleData["CellLabel", "Printout"], FontFamily -> "Courier", 
             FontSize -> 8, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Inline Formatting", "Section"], 
         Cell[
         "These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.", "Text"], 
         Cell[
          StyleData["RM"], StyleMenuListing -> None, FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
          StyleData["BF"], StyleMenuListing -> None, FontWeight -> "Bold"], 
         Cell[
          StyleData["IT"], StyleMenuListing -> None, FontSlant -> "Italic"], 
         Cell[
          StyleData["TR"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["TI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["TB"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["TBI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["MR"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["MO"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["MB"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["MBO"], StyleMenuListing -> None, FontFamily -> "Courier",
           FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["SR"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["SO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["SB"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["SBO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SO10"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10, FontWeight -> "Plain", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["SO10", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 7, FontWeight -> "Plain", 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["SO10", "EnhancedPrintout"], StyleMenuListing -> None, 
             FontFamily -> "Futura", FontSize -> 7, FontWeight -> "Plain", 
             FontSlant -> "Italic"]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineFormula"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 1, 
             SingleLetterItalics -> True], 
            Cell[
             StyleData["InlineFormula", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16], 
            Cell[
             StyleData["InlineFormula", "Condensed"], 
             CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["InlineFormula", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{42, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, ScriptLevel -> 0, SingleLetterItalics -> 
             True, UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             LineSpacing -> {1, 5}, FontSize -> 16], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["DisplayFormula", "Printout"], FontSize -> 10]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellFrame -> {{0, 0}, {0.5, 0.5}}, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, ScriptLevel -> 1, FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16], 
            Cell[
             StyleData["Program", "Condensed"], 
             CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}, FontSize -> 9]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Hyperlink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["MainBookLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["AddOnsLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["AddOnsLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuide", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["RefGuideLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"], FontSize -> 
             16], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"], FontSize -> 11], 
            
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontSize -> 10, FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          StyleMenuListing -> None, FontSize -> 9, FontSlant -> "Italic"], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 10]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Palette Styles", "Section"], 
         Cell[
         "The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.", "Text"], 
         Cell[
          StyleData["Paste"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, After]}]& )}], 
         Cell[
          StyleData["Evaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["EvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionMove[
                FrontEnd`InputNotebook[], All, Cell, 1], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Placeholder Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making placeholder objects \
in palette templates.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Placeholder"], Placeholder -> True, StyleMenuListing -> 
             None, FontSlant -> "Italic", FontColor -> 
             RGBColor[0.890623, 0.864698, 0.384756], 
             TagBoxOptions -> {
              Editable -> False, Selectable -> False, StripWrapperBoxes -> 
               False}], 
            Cell[
             StyleData["Placeholder", "Presentation"]], 
            Cell[
             StyleData["Placeholder", "Condensed"]], 
            Cell[
             StyleData["Placeholder", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PrimaryPlaceholder"], StyleMenuListing -> None, 
             DrawHighlighted -> True, FontSlant -> "Italic", Background -> 
             RGBColor[0.912505, 0.891798, 0.507774], 
             TagBoxOptions -> {
              Editable -> False, Selectable -> False, StripWrapperBoxes -> 
               False}], 
            Cell[
             StyleData["PrimaryPlaceholder", "Presentation"]], 
            Cell[
             StyleData["PrimaryPlaceholder", "Condensed"]], 
            Cell[
             StyleData["PrimaryPlaceholder", "Printout"]]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["FormatType Styles", "Section"], 
         Cell[
         "The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.", "Text"], 
         Cell[
          StyleData["CellExpression"], PageWidth -> Infinity, 
          CellMargins -> {{6, Inherited}, {Inherited, Inherited}}, 
          ShowCellLabel -> False, ShowSpecialCharacters -> False, 
          AllowInlineCells -> False, AutoItalicWords -> {}, StyleMenuListing -> 
          None, FontFamily -> "Courier", FontSize -> 12, Background -> 
          GrayLevel[1]], 
         Cell[
          StyleData["InputForm"], AllowInlineCells -> False, StyleMenuListing -> 
          None, FontFamily -> "Courier"], 
         Cell[
          StyleData["OutputForm"], PageWidth -> Infinity, TextAlignment -> 
          Left, LineSpacing -> {0.6, 1}, StyleMenuListing -> None, FontFamily -> 
          "Courier"], 
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0}, 
          StyleMenuListing -> None, FontFamily -> "Courier"], 
         Cell[
          StyleData["TraditionalForm"], LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> True, TraditionalFunctionNotation -> True, 
          DelimiterMatching -> None, StyleMenuListing -> None], 
         Cell[
         "The style defined below is mixed in to any cell that is in an \
inline cell within another.", "Text"], 
         Cell[
          StyleData["InlineCell"], TextAlignment -> Left, ScriptLevel -> 1, 
          StyleMenuListing -> None], 
         Cell[
          StyleData["InlineCellEditing"], StyleMenuListing -> None, 
          Background -> RGBColor[1, 0.749996, 0.8]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Automatic Styles", "Section"], 
         Cell[
         "The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).", "Text"], 
         Cell[
          StyleData["UnmatchedBracket"], StyleMenuListing -> None, FontColor -> 
          RGBColor[0.760006, 0.330007, 0.8]]}, Closed]]}, Open]]}, Visible -> 
  False, FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 340, 9, 173, "Title",
 Evaluatable->False],
Cell[922, 33, 135, 3, 73, "Subtitle"],
Cell[1060, 38, 380, 12, 80, "Subtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1465, 54, 102, 2, 60, "Section",
 Evaluatable->False],
Cell[1570, 58, 2818, 71, 714, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[4425, 134, 87, 2, 60, "Section",
 Evaluatable->False],
Cell[4515, 138, 461, 16, 83, "Text",
 Evaluatable->False],
Cell[4979, 156, 45, 1, 33, "Input"],
Cell[5027, 159, 103, 2, 35, "Text",
 Evaluatable->False],
Cell[5133, 163, 61, 1, 33, "Input"],
Cell[5197, 166, 79, 2, 35, "Text",
 Evaluatable->False],
Cell[5279, 170, 79, 1, 33, "Input"],
Cell[5361, 173, 84, 2, 35, "Text",
 Evaluatable->False],
Cell[5448, 177, 172, 5, 59, "Text",
 Evaluatable->False],
Cell[5623, 184, 46, 1, 33, "Input"],
Cell[5672, 187, 458, 12, 107, "Text",
 Evaluatable->False],
Cell[6133, 201, 50, 1, 33, "Input"],
Cell[6186, 204, 64, 2, 35, "Text",
 Evaluatable->False],
Cell[6253, 208, 46, 1, 33, "Input"],
Cell[6302, 211, 187, 5, 59, "Text",
 Evaluatable->False],
Cell[6492, 218, 288, 8, 83, "Text",
 Evaluatable->False],
Cell[6783, 228, 48, 1, 33, "Input"],
Cell[6834, 231, 53, 1, 33, "Input"],
Cell[6890, 234, 235, 7, 59, "Text",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[7162, 246, 73, 2, 40, "Section",
 Evaluatable->False],
Cell[7238, 250, 247, 8, 59, "Text",
 Evaluatable->False],
Cell[7488, 260, 231, 7, 33, "Input"],
Cell[7722, 269, 253, 8, 59, "Text",
 Evaluatable->False],
Cell[7978, 279, 162, 5, 59, "Text",
 Evaluatable->False],
Cell[8143, 286, 371, 12, 33, "Input"],
Cell[8517, 300, 366, 12, 33, "Input"],
Cell[8886, 314, 341, 14, 36, "Text",
 Evaluatable->False],
Cell[9230, 330, 105, 2, 35, "Text",
 Evaluatable->False],
Cell[9338, 334, 864, 24, 144, "Input"],
Cell[10205, 360, 329, 11, 83, "Text",
 Evaluatable->False],
Cell[10537, 373, 57, 1, 33, "Input"],
Cell[10597, 376, 347, 11, 83, "Text",
 Evaluatable->False],
Cell[10947, 389, 695, 18, 115, "Input"],
Cell[11645, 409, 60, 1, 33, "Input"],
Cell[11708, 412, 207, 5, 59, "Text",
 Evaluatable->False],
Cell[11918, 419, 2726, 79, 331, "Input"],
Cell[14647, 500, 280, 10, 59, "Text",
 Evaluatable->False],
Cell[14930, 512, 197, 7, 35, "Text",
 Evaluatable->False],
Cell[15130, 521, 634, 19, 88, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[15801, 545, 85, 2, 40, "Section",
 Evaluatable->False],
Cell[15889, 549, 186, 6, 35, "Text",
 Evaluatable->False],
Cell[16078, 557, 61, 1, 33, "Input"],
Cell[16142, 560, 93, 2, 35, "Text",
 Evaluatable->False],
Cell[16238, 564, 59, 1, 33, "Input"],
Cell[16300, 567, 77, 2, 35, "Text",
 Evaluatable->False],
Cell[16380, 571, 59, 1, 33, "Input"],
Cell[16442, 574, 110, 2, 35, "Text",
 Evaluatable->False],
Cell[16555, 578, 83, 2, 33, "Input"],
Cell[16641, 582, 115, 2, 35, "Text",
 Evaluatable->False],
Cell[16759, 586, 55, 1, 33, "Input"],
Cell[16817, 589, 100, 2, 35, "Text",
 Evaluatable->False],
Cell[16920, 593, 53, 1, 33, "Input"],
Cell[16976, 596, 316, 11, 59, "Text",
 Evaluatable->False],
Cell[17295, 609, 79, 1, 33, "Input"],
Cell[17377, 612, 94, 2, 35, "Text",
 Evaluatable->False],
Cell[17474, 616, 77, 2, 33, "Input"],
Cell[17554, 620, 303, 7, 83, "Text",
 Evaluatable->False],
Cell[17860, 629, 446, 16, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[18343, 650, 82, 2, 40, "Section",
 Evaluatable->False],
Cell[18428, 654, 82, 2, 35, "Text",
 Evaluatable->False],
Cell[18513, 658, 66, 1, 33, "Input"],
Cell[18582, 661, 82, 2, 35, "Text",
 Evaluatable->False],
Cell[18667, 665, 55, 1, 33, "Input"],
Cell[18725, 668, 273, 8, 59, "Text",
 Evaluatable->False],
Cell[19001, 678, 77, 1, 33, "Input"],
Cell[19081, 681, 170, 7, 35, "Text",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[19288, 693, 70, 2, 40, "Section",
 Evaluatable->False],
Cell[19361, 697, 251, 8, 59, "Text",
 Evaluatable->False],
Cell[19615, 707, 79, 1, 33, "Input"],
Cell[19697, 710, 92, 2, 35, "Text",
 Evaluatable->False],
Cell[19792, 714, 69, 1, 33, "Input"],
Cell[19864, 717, 87, 2, 35, "Text",
 Evaluatable->False],
Cell[19954, 721, 73, 1, 33, "Input"],
Cell[20030, 724, 95, 2, 35, "Text",
 Evaluatable->False],
Cell[20128, 728, 73, 1, 33, "Input"],
Cell[20204, 731, 132, 4, 35, "Text",
 Evaluatable->False],
Cell[20339, 737, 401, 13, 67, "Input"],
Cell[20743, 752, 95, 2, 33, "Input"],
Cell[20841, 756, 215, 7, 59, "Text",
 Evaluatable->False],
Cell[21059, 765, 58, 1, 33, "Input"],
Cell[21120, 768, 67, 2, 35, "Text",
 Evaluatable->False],
Cell[21190, 772, 55, 1, 33, "Input"],
Cell[21248, 775, 117, 2, 35, "Text",
 Evaluatable->False],
Cell[21368, 779, 56, 1, 33, "Input"],
Cell[21427, 782, 60, 1, 33, "Input"],
Cell[21490, 785, 135, 4, 35, "Text",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[21662, 794, 83, 2, 40, "Section",
 Evaluatable->False],
Cell[21748, 798, 87, 2, 35, "Text",
 Evaluatable->False],
Cell[21838, 802, 71, 1, 33, "Input"],
Cell[21912, 805, 71, 2, 35, "Text",
 Evaluatable->False],
Cell[21986, 809, 49, 1, 33, "Input"],
Cell[22038, 812, 97, 2, 35, "Text",
 Evaluatable->False],
Cell[22138, 816, 50, 1, 33, "Input"],
Cell[22191, 819, 103, 2, 35, "Text",
 Evaluatable->False],
Cell[22297, 823, 52, 1, 33, "Input"],
Cell[22352, 826, 86, 2, 35, "Text",
 Evaluatable->False],
Cell[22441, 830, 58, 1, 33, "Input"],
Cell[22502, 833, 137, 4, 35, "Text",
 Evaluatable->False],
Cell[22642, 839, 65, 1, 33, "Input"],
Cell[22710, 842, 64, 1, 33, "Input"],
Cell[22777, 845, 112, 2, 35, "Text",
 Evaluatable->False],
Cell[22892, 849, 66, 1, 33, "Input"],
Cell[22961, 852, 218, 5, 59, "Text",
 Evaluatable->False],
Cell[23182, 859, 148, 4, 59, "Text",
 Evaluatable->False],
Cell[23333, 865, 64, 1, 33, "Input"],
Cell[23400, 868, 65, 1, 33, "Input"],
Cell[23468, 871, 64, 1, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[23569, 877, 92, 2, 40, "Section",
 Evaluatable->False],
Cell[23664, 881, 295, 8, 83, "Text",
 Evaluatable->False],
Cell[23962, 891, 55, 1, 33, "Input"],
Cell[24020, 894, 91, 2, 35, "Text",
 Evaluatable->False],
Cell[24114, 898, 59, 1, 33, "Input"],
Cell[24176, 901, 133, 4, 35, "Text",
 Evaluatable->False],
Cell[24312, 907, 57, 1, 33, "Input"],
Cell[24372, 910, 205, 5, 59, "Text",
 Evaluatable->False],
Cell[24580, 917, 67, 1, 33, "Input"],
Cell[24650, 920, 116, 2, 35, "Text",
 Evaluatable->False],
Cell[24769, 924, 59, 1, 33, "Input"],
Cell[24831, 927, 138, 4, 35, "Text",
 Evaluatable->False],
Cell[24972, 933, 65, 1, 33, "Input"],
Cell[25040, 936, 205, 7, 59, "Text",
 Evaluatable->False],
Cell[25248, 945, 90, 2, 33, "Input"],
Cell[25341, 949, 184, 7, 35, "Text",
 Evaluatable->False],
Cell[25528, 958, 94, 2, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[25659, 965, 70, 2, 40, "Section",
 Evaluatable->False],
Cell[25732, 969, 185, 6, 35, "Text",
 Evaluatable->False],
Cell[25920, 977, 256, 8, 33, "Input"],
Cell[26179, 987, 178, 7, 35, "Text",
 Evaluatable->False],
Cell[26360, 996, 265, 8, 33, "Input"],
Cell[26628, 1006, 295, 9, 33, "Input"],
Cell[26926, 1017, 250, 6, 83, "Text",
 Evaluatable->False],
Cell[27179, 1025, 296, 9, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[27512, 1039, 72, 2, 40, "Section",
 Evaluatable->False],
Cell[27587, 1043, 200, 7, 35, "Text",
 Evaluatable->False],
Cell[27790, 1052, 833, 25, 169, "Input"],
Cell[28626, 1079, 110, 2, 35, "Text",
 Evaluatable->False],
Cell[28739, 1083, 58, 1, 33, "Input"],
Cell[28800, 1086, 266, 7, 59, "Text",
 Evaluatable->False],
Cell[29069, 1095, 123, 3, 33, "Input"],
Cell[29195, 1100, 159, 5, 59, "Text",
 Evaluatable->False],
Cell[29357, 1107, 50, 1, 33, "Input"],
Cell[29410, 1110, 325, 10, 108, "Text",
 Evaluatable->False],
Cell[29738, 1122, 47, 1, 33, "Input"],
Cell[29788, 1125, 218, 7, 83, "Text",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[30043, 1137, 85, 2, 40, "Section",
 Evaluatable->False],
Cell[30131, 1141, 381, 11, 107, "Text",
 Evaluatable->False],
Cell[30515, 1154, 273, 9, 33, "Input"],
Cell[30791, 1165, 64, 1, 33, "Input"],
Cell[30858, 1168, 141, 4, 35, "Text",
 Evaluatable->False],
Cell[31002, 1174, 158, 4, 61, "Input"],
Cell[31163, 1180, 115, 3, 61, "Input"],
Cell[31281, 1185, 149, 4, 88, "Input"],
Cell[31433, 1191, 116, 3, 61, "Input"],
Cell[31552, 1196, 92, 2, 35, "Text",
 Evaluatable->False],
Cell[31647, 1200, 121, 3, 61, "Input"],
Cell[31771, 1205, 185, 5, 64, "Input"],
Cell[31959, 1212, 346, 11, 61, "Input"],
Cell[32308, 1225, 244, 7, 61, "Input"],
Cell[32555, 1234, 231, 7, 61, "Input"],
Cell[32789, 1243, 155, 5, 59, "Text",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[32981, 1253, 74, 2, 40, "Section",
 Evaluatable->False],
Cell[33058, 1257, 206, 7, 59, "Text",
 Evaluatable->False],
Cell[33267, 1266, 60, 1, 33, "Input"],
Cell[33330, 1269, 80, 2, 35, "Text",
 Evaluatable->False],
Cell[33413, 1273, 69, 1, 33, "Input"],
Cell[33485, 1276, 64, 2, 35, "Text",
 Evaluatable->False],
Cell[33552, 1280, 77, 1, 33, "Input"],
Cell[33632, 1283, 213, 5, 59, "Text",
 Evaluatable->False],
Cell[33848, 1290, 52, 1, 33, "Input"],
Cell[33903, 1293, 52, 1, 33, "Input"],
Cell[33958, 1296, 52, 1, 33, "Input"],
Cell[34013, 1299, 187, 5, 59, "Text",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[34237, 1309, 76, 2, 40, "Section",
 Evaluatable->False],
Cell[34316, 1313, 171, 7, 35, "Text",
 Evaluatable->False],
Cell[34490, 1322, 244, 8, 59, "Text",
 Evaluatable->False],
Cell[34737, 1332, 94, 4, 55, "Input"],
Cell[34834, 1338, 71, 2, 35, "Text",
 Evaluatable->False],
Cell[34908, 1342, 52, 1, 33, "Input"],
Cell[34963, 1345, 636, 15, 179, "Text",
 Evaluatable->False],
Cell[35602, 1362, 106, 4, 55, "Input"],
Cell[35711, 1368, 61, 1, 33, "Input"],
Cell[35775, 1371, 67, 1, 33, "Input"],
Cell[35845, 1374, 65, 1, 33, "Input"],
Cell[35913, 1377, 184, 5, 59, "Text",
 Evaluatable->False],
Cell[36100, 1384, 537, 13, 131, "Text",
 Evaluatable->False],
Cell[36640, 1399, 209, 8, 143, "Input"],
Cell[36852, 1409, 69, 1, 33, "Input"],
Cell[36924, 1412, 198, 7, 35, "Text",
 Evaluatable->False],
Cell[37125, 1421, 29, 0, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[37191, 1426, 138, 6, 40, "Section",
 Evaluatable->False],
Cell[37332, 1434, 520, 12, 107, "Text",
 Evaluatable->False],
Cell[37855, 1448, 151, 3, 33, "Input"],
Cell[38009, 1453, 73, 1, 33, "Input"],
Cell[38085, 1456, 70, 1, 33, "Input"],
Cell[38158, 1459, 213, 4, 35, "Text"],
Cell[38374, 1465, 124, 2, 33, "Input"],
Cell[38501, 1469, 121, 2, 33, "Input"],
Cell[38625, 1473, 159, 4, 33, "Input",
 CellID->1510471140],
Cell[38787, 1479, 139, 2, 33, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
